@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0914';
+our $VERSION = '0.1000';
 
 use v5.36;
 
@@ -13,24 +13,11 @@ use IO::Async::Timer::Countdown ();
 use IO::Async::Timer::Periodic ();
 use Iterator::Breathe ();
 use Moo;
-use Types::MIDI qw(Channel Velocity);
+use Types::MIDI qw(Velocity);
 use Types::Common::Numeric qw(PositiveNum);
-use Types::Standard qw(Bool Maybe);
 use namespace::clean;
 
-
-has rtc => (
-    is  => 'ro',
-    isa => sub { die 'Invalid rtc' unless ref($_[0]) eq 'MIDI::RtController' },
-    required => 1,
-);
-
-
-has channel => (
-    is      => 'rw',
-    isa     => Channel,
-    default => 0,
-);
+extends 'MIDI::RtController::Filter';
 
 
 has control => (
@@ -40,20 +27,6 @@ has control => (
 );
 
 
-has value => (
-    is      => 'rw',
-    isa     => Maybe[Velocity], # no CC# in Types::MIDI yet
-    default => undef,
-);
-
-
-has trigger => (
-    is      => 'rw',
-    isa     => Maybe[Velocity], # no CC# in Types::MIDI yet
-    default => undef,
-);
-
-
 has initial_point => (
     is      => 'rw',
     isa     => Velocity, # no CC# msg value in Types::MIDI yet
@@ -103,20 +76,6 @@ has step_down => (
 );
 
 
-has running => (
-    is      => 'rw',
-    isa     => Bool,
-    default => 0,
-);
-
-
-has halt => (
-    is      => 'rw',
-    isa     => Bool,
-    default => 0,
-);
-
-
 sub add_filters ($filters, $controllers) {
     for my $params (@$filters) {
         my $port = delete $params->{port};
@@ -376,7 +335,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0914
+version 0.1000
 
 =head1 SYNOPSIS
 
@@ -430,22 +389,6 @@ not.
 
 =head1 ATTRIBUTES
 
-=head2 rtc
-
-  $rtc = $filter->rtc;
-
-The required L<MIDI::RtController> instance provided in the
-constructor.
-
-=head2 channel
-
-  $channel = $filter->channel;
-  $filter->channel($number);
-
-The current MIDI channel value between C<0> and C<15>.
-
-Default: C<0>
-
 =head2 control
 
   $control = $filter->control;
@@ -455,28 +398,6 @@ Return or set the control change number between C<0> and C<127>.
 
 Default: C<1> (mod-wheel)
 
-=head2 value
-
-  $value = $filter->value;
-  $filter->value($number);
-
-Return or set the MIDI event value. This is a generic setting that can
-be used by filters to set or retrieve state and can be any whole
-number between C<0> and C<127> or C<undef>.
-
-Default: C<undef>
-
-=head2 trigger
-
-  $trigger = $filter->trigger;
-  $filter->trigger($number);
-
-Return or set the trigger. This is a generic setting that can be used
-by filters to set or retrieve state and can be any whole number
-between C<0> and C<127> or C<undef>.
-
-Default: C<undef>
-
 =head2 initial_point
 
   $initial_point = $filter->initial_point;
@@ -544,24 +465,6 @@ between C<0> and C<127>.
 
 Default: C<1>
 
-=head2 running
-
-  $running = $filter->running;
-  $filter->running($boolean);
-
-Are we running a filter?
-
-Default: C<0>
-
-=head2 halt
-
-  $halt = $filter->halt;
-  $filter->halt($boolean);
-
-This Boolean can be used to terminate B<running> filters.
-
-Default: C<0>
-
 =head1 METHODS
 
 =head2 new
